package com.fzm.portal.controller;

import cn.hutool.crypto.SecureUtil;
import com.fzm.common.annotation.Authentication;
import com.fzm.common.entity.CommemorateNft;
import com.fzm.common.entity.Label;
import com.fzm.common.entity.User;
import com.fzm.common.enums.ResultCode;
import com.fzm.common.exception.GlobalException;
import com.fzm.common.model.ResponseModel;
import com.fzm.common.service.CommemorateNftService;
import com.fzm.common.service.LabelService;
import com.fzm.common.service.UserService;
import com.fzm.common.utils.OssUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;

/**
 * @author tangtuo
 * @date 2021/7/1 14:37
 */
@RestController
@RequestMapping(value = "/commemorate/nft")
@Api(tags = "纪念版nft")
public class CommemorateNftController {

    @Resource
    private CommemorateNftService commemorateNftService;

    @Resource
    private OssUtil ossUtil;

    @Authentication
    @PostMapping("/publish")
    @ApiOperation(value = "发行纪念版nft", notes = "返回发行成功的数量")
    public ResponseModel<Integer> publish(@ApiParam(value = "作品名称", required = true) String name,
                                          @ApiParam(value = "作品简介", required = true) String synopsis,
                                          @ApiParam(value = "类目id", required = true) Integer categoryId,
                                          @ApiParam(value = "文件", required = true) MultipartFile file,
                                          @ApiParam(value = "发行数量", required = true) Integer count) throws IOException {
        if (file == null) {
            throw GlobalException.newException(ResultCode.VALIDATE_FAILED, "文件不能为空");
        }
        String url = ossUtil.putSimpleObject(file);
        CommemorateNft commemorateNft = new CommemorateNft().
                setName(name).
                setCount(count).
                setSynopsis(synopsis).
                setFileName(file.getOriginalFilename()).
                setFileUrl(url).
                setCategoryId(categoryId).
                setFileHash(SecureUtil.md5(file.getInputStream()));
        Integer id = commemorateNftService.publish(commemorateNft);
        return ResponseModel.success(id);
    }

    @Authentication
    @PostMapping("/receive")
    @ApiOperation(value = "领取纪念版nft")
    public ResponseModel<Boolean> receive(@RequestParam Integer id) {
       Boolean result = commemorateNftService.receive(id);
        return ResponseModel.success();
    }
}
